#
# spec file for package python-XlsxWriter
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-XlsxWriter
Version:        0.9.3
Release:        1.1
Summary:        Python module for writing OOXML spreadsheet files
License:        BSD-2-Clause
Group:          Development/Languages/Python
Url:            https://xlsxwriter.readthedocs.org/
Source:         https://files.pythonhosted.org/packages/source/X/XlsxWriter/XlsxWriter-%{version}.tar.gz
BuildRequires:  python-devel
BuildRequires:  python-setuptools
Requires(post): update-alternatives
Requires(postun): update-alternatives
# python-xlsxwriter was last used in openSUSE Leap 42.1.
Provides:       python-xlsxwriter = %{version}
Obsoletes:      python-xlsxwriter < %{version}
%if 0%{?suse_version} >= 1120
BuildArch:      noarch
%else
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%py_requires
%endif

%description
XlsxWriter is a Python module for writing files in the Microsoft
Office Open XML spreadsheet format. It can be used to write text,
numbers, formulas and hyperlinks to multiple worksheets and it
supports features such as formatting and many more.

%prep
%setup -q -n XlsxWriter-%{version}

%build
python2 setup.py build

%install
python2 setup.py install \
  --root=%{buildroot} --prefix=%{_prefix}

# Prepare for update-alternatives usage.
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
mv %{buildroot}%{_bindir}/vba_extract.py \
  %{buildroot}%{_bindir}/vba_extract-%{py_ver}
ln -sf %{_sysconfdir}/alternatives/vba_extract %{buildroot}%{_bindir}/vba_extract
# Create a dummy target for /etc/alternatives/vba_extract.
touch %{buildroot}%{_sysconfdir}/alternatives/vba_extract

%post
"%{_sbindir}/update-alternatives" \
  --install %{_bindir}/vba_extract vba_extract %{_bindir}/vba_extract-%{py_ver} 30

%postun
if [ $1 -eq 0 ] ; then
    "%{_sbindir}/update-alternatives" --remove vba_extract %{_bindir}/vba_extract-%{py_ver}
fi

%files
%defattr(-,root,root)
%doc Changes LICENSE.txt README.rst
%ghost %{_sysconfdir}/alternatives/vba_extract
%{_bindir}/vba_extract
%{_bindir}/vba_extract-%{py_ver}
%{python_sitelib}/xlsxwriter/
%{python_sitelib}/XlsxWriter-%{version}-py*.egg-info

%changelog
* Fri Jul 22 2016 sor.alexei@meowr.ru
- Update to version 0.9.3 (changes since 0.8.7):
  * Add workbook :func:`set_custom_property` method to set custom
    document properties.
  * Fix for :func:`insert_image` issue when handling images with
    zero dpi.
  * Add :ref:`trendline properties <chart_series_option_trendline>`:
  ``intercept``, ``display_equation`` and ``display_r_squared``.
  * Documented used of font rotation in chart :ref:`data labels
    <chart_series_option_data_labels>`.
  * Add workbook :func:`set_size` method to set the workbook window
    size.
  * Add check to :func:`add_table` to prevent duplicate header
    names which leads to a corrupt Excel file.
- Fix SLE 11 build.
* Wed May 25 2016 toddrme2178@gmail.com
- Update to 0.8.7
  * Fix for issue when inserting read-only images on Windows.
    Issue `#352 <https://github.com/jmcnamara/XlsxWriter/issues/352>`_.
  * Added :func:`get_worksheet_by_name()` method to allow the retrieval of a
    worksheet from a workbook via its name.
  * Fixed issue where internal file creation and modification dates where in the
    local timezone instead of UTC.
- Switch to pythonhosted URL.
- Rename to python3-XlsxWriter to conform to python packaging guidelines
- Implement update-alternatives
* Thu Apr 28 2016 sor.alexei@meowr.ru
- Update to version 0.8.6 (changes since 0.8.4):
  * Add additional documentation on :ref:`ewx_pandas` and
    :ref:`pandas_examples`.
  * Add fix for :func:`set_center_across` format method.
  * Fix for ``external:`` urls where the target/anchor contains
    spaces.
* Thu Feb 11 2016 sor.alexei@meowr.ru
- Update to 0.8.4 (changes since 0.7.7):
  * Add checks for valid and non-duplicate worksheet table names.
  * Add chart pattern fills, see :ref:`chart_formatting_pattern`
    and :ref:`ex_chart_pattern`.
  * Add additional documentation on :ref:`working_with_formulas`.
  * Add option to set chart tick interval.
  * Add transparency option to solid fill colours in chart areas
    (:ref:`chart_formatting_fill`).
  * Add options to configure chart axis tick placement.
    See :func:`set_x_axis()`.
  * Fix for :func:`write_url` exception when the URL contains two
    ``#`` location/anchors. Note, URLs like this aren't strictly
    valid and cannot be entered manually in Excel.
* Mon Nov 23 2015 sor.alexei@meowr.ru
- Update to 0.7.7:
  * Add support for table header formatting and a fix for wrapped
    lines in the header.
* Sat Oct 10 2015 sor.alexei@meowr.ru
- Update to 0.7.6:
  * Add option to allow data validation input messages with the
    'any' validate parameter.
  * Fix url encoding of links to external files and directories.
  * Allow hyperlinks longer than 255 characters when the link and
    anchor are each less than or equal to 255 characters.
  * Add ``hyperlink_base`` document property.
  * Fix for images with negative offsets.
* Sat Jul 18 2015 sor.alexei@meowr.ru
- Initial package.
